==> electron-inspector-0.1.3.tgz: package/lib/rebuild.js <==
// Copyright (c) 2016 Vadim Macagon
// MIT License, see LICENSE file for full terms.
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator.throw(value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments)).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t;
    return { next: verb(0), "throw": verb(1), "return": verb(2) };
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = y[op[0] & 2 ? "return" : op[0] ? "throw" : "next"]) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [0, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var path = require("path");
var electron_rebuild_1 = require("electron-rebuild");
var node_pre_gyp_fix_1 = require("electron-rebuild/lib/node-pre-gyp-fix");
/**
 * Rebuild any native NodeJS modules in the given `node_modules` directory to work with the
 * specified Electron runtime. If the Electron path and version are not specified they'll be
 * obtained from the `electron-prebuilt` package.
 */
function rebuild(executablePath, version, arch) {
    return __awaiter(this, void 0, void 0, function () {
        var modulesDir;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    modulesDir = path.join(__dirname, '../node_modules');
                    console.log("Rebuilding native node-inspector modules for Electron " + version);
                    return [4 /*yield*/, electron_rebuild_1.installNodeHeaders(version, null, null, arch)];
                case 1:
                    _a.sent();
                    console.log("Rebuilding " + modulesDir + "/v8-profiler");
                    return [4 /*yield*/, electron_rebuild_1.rebuildNativeModules(version, modulesDir, 'v8-profiler', null, arch)];
                case 2:
                    _a.sent();
                    // `node-inspector` will be launched in a "run as node" Electron process,
                    // so `node-pre-gyp` will be looking for a `node-vXX-platform-arch` directory
                    return [4 /*yield*/, node_pre_gyp_fix_1.preGypFixRun(path.join(modulesDir, 'v8-profiler'), true, executablePath)];
                case 3:
                    // `node-inspector` will be launched in a "run as node" Electron process,
                    // so `node-pre-gyp` will be looking for a `node-vXX-platform-arch` directory
                    _a.sent();
                    console.log("Rebuilding " + modulesDir + "/v8-debug");
                    return [4 /*yield*/, electron_rebuild_1.rebuildNativeModules(version, modulesDir, 'v8-debug', null, arch)];
                case 4:
                    _a.sent();
                    return [4 /*yield*/, node_pre_gyp_fix_1.preGypFixRun(path.join(modulesDir, 'v8-debug'), true, executablePath)];
                case 5:
                    _a.sent();
                    console.log("Done.");
                    return [2 /*return*/];
            }
        });
    });
}
exports.rebuild = rebuild;

==> electron-inspector-0.1.4.tgz: package/lib/rebuild.js <==
// Copyright (c) 2016 Vadim Macagon
// MIT License, see LICENSE file for full terms.
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments)).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t;
    return { next: verb(0), "throw": verb(1), "return": verb(2) };
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = y[op[0] & 2 ? "return" : op[0] ? "throw" : "next"]) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [0, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var path = require("path");
var electron_rebuild_1 = require("electron-rebuild");
var node_pre_gyp_fix_1 = require("electron-rebuild/lib/node-pre-gyp-fix");
/**
 * Rebuild any native NodeJS modules in the given `node_modules` directory to work with the
 * specified Electron runtime. If the Electron path and version are not specified they'll be
 * obtained from the `electron-prebuilt` package.
 */
function rebuild(executablePath, version, arch) {
    return __awaiter(this, void 0, void 0, function () {
        var modulesDir;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    modulesDir = path.join(__dirname, '../node_modules');
                    console.log("Rebuilding native node-inspector modules for Electron " + version);
                    return [4 /*yield*/, electron_rebuild_1.installNodeHeaders(version, null, null, arch)];
                case 1:
                    _a.sent();
                    console.log("Rebuilding " + modulesDir + "/v8-profiler");
                    return [4 /*yield*/, electron_rebuild_1.rebuildNativeModules(version, modulesDir, 'v8-profiler', null, arch)];
                case 2:
                    _a.sent();
                    // `node-inspector` will be launched in a "run as node" Electron process,
                    // so `node-pre-gyp` will be looking for a `node-vXX-platform-arch` directory
                    return [4 /*yield*/, node_pre_gyp_fix_1.preGypFixRun(path.join(modulesDir, 'v8-profiler'), true, executablePath)];
                case 3:
                    // `node-inspector` will be launched in a "run as node" Electron process,
                    // so `node-pre-gyp` will be looking for a `node-vXX-platform-arch` directory
                    _a.sent();
                    console.log("Rebuilding " + modulesDir + "/v8-debug");
                    return [4 /*yield*/, electron_rebuild_1.rebuildNativeModules(version, modulesDir, 'v8-debug', null, arch)];
                case 4:
                    _a.sent();
                    return [4 /*yield*/, node_pre_gyp_fix_1.preGypFixRun(path.join(modulesDir, 'v8-debug'), true, executablePath)];
                case 5:
                    _a.sent();
                    console.log("Done.");
                    return [2 /*return*/];
            }
        });
    });
}
exports.rebuild = rebuild;
